from ...._decorators import abaqus_class_doc, abaqus_method_doc

@abaqus_class_doc
class UserOutputVariables:
    """The UserOutputVariables object specifies the number of user-defined output variables.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].userOutputVariables
            import odbMaterial
            session.odbs[name].materials[name].userOutputVariables

        The corresponding analysis keywords are:

        - USER OUTPUT VARIABLES
    """

    @abaqus_method_doc
    def __init__(self, n: int = 0):
        """This method creates a UserOutputVariables object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].UserOutputVariables
                session.odbs[name].materials[name].UserOutputVariables

        Parameters
        ----------
        n
            An Int specifying the number of user-defined variables required at each material point.
            The default value is 0.

        Returns
        -------
        UserOutputVariables
            A :py:class:`~abaqus.Material.Others.User.UserOutputVariables.UserOutputVariables` object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the UserOutputVariables object.

        Raises
        ------
        RangeError
        """
        ...



from .._decorators import abaqus_class_doc


@abaqus_class_doc
class Datum:
    """The Datum object is the abstract base type for other Datum objects. The Datum object has
    no explicit constructor. The methods and members of the Datum object are common to all
    objects derived from the Datum.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import part
            mdb.models[name].parts[name].datums[i]
            import assembly
            mdb.models[name].rootAssembly.allInstances[name].datums[i]
            mdb.models[name].rootAssembly.datums[i]
            mdb.models[name].rootAssembly.instances[name].datums[i]
            mdb.models[name].rootAssembly.modelInstances[i].datums[i]
    """

    ...



from .Field import Field
from .OdbMeshRegionData import OdbMeshRegionData
from ..Datum.DatumCsys import DatumCsys
from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class AnalyticalField(Field):
    """The AnalyticalField object is the abstract base type for other AnalyticalField objects.
    The AnalyticalField object has no explicit constructor. The methods and members of the
    AnalyticalField object are common to all objects derived from the AnalyticalField.
    The AnalyticalField object is derived from the Field object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import fields
            mdb.models[name].analyticalFields[name]
    """

    #: A String specifying the repository key.
    name: str = ""

    #: None or a DatumCsys object specifying the local coordinate system of the field. If
    #: **localCsys** = None, the field is defined in the global coordinate system. The default
    #: value is None.
    localCsys: DatumCsys = DatumCsys()

    #: A String specifying the description of the field. The default value is an empty string.
    description: str = ""

    #: An :py:class:`~abaqus.Field.OdbMeshRegionData.OdbMeshRegionData` object.
    odbMeshRegionData: OdbMeshRegionData = OdbMeshRegionData("", "")

    @abaqus_method_doc
    def OdbMeshRegionData(
        self,
        odbFileName: str,
        variableLabel: str,
        stepIndex: int = 0,
        frameIndex: int = 0,
        outputPosition: SymbolicConstant = UNDEFINED_POSITION,
        dataType: SymbolicConstant = SCALAR,
        storageType: SymbolicConstant = FLOAT,
        quantityToPlot: SymbolicConstant = FIELD_OUTPUT,
        averageElementOutput: str = OFF,
        useRegionBoundaries: str = OFF,
        regionBoundaries: SymbolicConstant = NONE,
        includeFeatureBoundaries: str = ON,
        featureAngle: float = 20,
        averageOnlyDisplayed: str = OFF,
        averagingThreshold: float = 75,
        computeOrder: SymbolicConstant = EXTRAPOLATE_COMPUTE_AVERAGE,
        numericForm: SymbolicConstant = REAL,
        complexAngle: float = 0,
        sectionPoint: str = "",
        refinementType: SymbolicConstant = None,
        refinementLabel: str = "",
        displayOutputPosition: SymbolicConstant = None,
    ) -> OdbMeshRegionData:
        """This method creates an OdbMeshRegionData object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].analyticalFields[name].OdbMeshRegionData

        Parameters
        ----------
        odbFileName
            A String specifying the name of the output database file (including the .odb extension)
            to be read into as the source data. This String can also be the full path to the output
            database file if it is located in another directory.
        variableLabel
            A String specifying the field output variable.
        stepIndex
            An Int specifying the step index. Possible values are 0 ≤ **stepIndex** ≤ (**numSteps** −
            1). The default value is 0.
        frameIndex
            An Int specifying the frame in the specified step. Valid values are 0 ≤ **frameIndex** ≤
            (**numFramesInStep** − 1). The default value is 0.
        outputPosition
            A SymbolicConstant specifying the position where the data is written in the output
            database. Data can be obtained only from the position at which it was written to the
            output database during the analysis. This position should be aligned with the field
            output variable. Possible values are:
            
            - UNDEFINED_POSITION
            - NODAL
            - INTEGRATION_POINT
            - ELEMENT_FACE
            - ELEMENT_NODAL
            - ELEMENT_CENTROID
            - WHOLE_ELEMENT
            - WHOLE_REGION
            - WHOLE_PART_INSTANCE
            - WHOLE_MODEL
            - GENERAL_PARTICLE
            
            The default value is UNDEFINED_POSITION.
        dataType
            A SymbolicConstant specifying the data type of the field output variable which should be
            aligned with the variable. Currently only SCALAR is supported. Possible values are:
            
            - ENUMERATION
            - BOOLEAN
            - INTEGER
            - SCALAR
            - VECTOR
            - QUATERNION_2D
            - QUATERNION_3D
            - TENSOR
            - TENSOR_3D_FULL
            - TENSOR_3D_PLANAR
            - TENSOR_3D_SURFACE
            - TENSOR_2D_PLANAR
            - TENSOR_2D_SURFACE
            
            The default value is SCALAR.
        storageType
            A SymbolicConstant specifying the storage type of the field output variable which
            should be aligned with the variable. Possible values are FLOAT, DOUBLE, INTEGER, and
            BOOLEAN. The default value is FLOAT.
        quantityToPlot
            A SymbolicConstant specifying the quantity to plot. Currently only FIELD_OUTPUT is
            supported. Possible values are FIELD_OUTPUT and DISCONTINUITIES. The default value is
            FIELD_OUTPUT.
        averageElementOutput
            A Boolean specifying whether to average the element output. The default value is OFF.
        useRegionBoundaries
            A Boolean specifying whether to use region boundaries when averaging. The default
            value is OFF.
        regionBoundaries
            A SymbolicConstant specifying the type of averaging region boundaries. Currently only
            NONE and ODB_REGIONS are supported. Possible values are NONE, ODB_REGIONS, ELEMENT_SET,
            and DISPLAY_GROUPS. The default value is NONE.
        includeFeatureBoundaries
            A Boolean specifying whether to include additional averaging boundaries for shells and
            membranes based on feature edges. The default value is ON.
        featureAngle
            A Float specifying the feature angle to be used when **includeFeatureBoundaries** = ON.
            The default value is 20.0.
        averageOnlyDisplayed
            A Boolean specifying whether to average only values on displayed elements. The default
            value is OFF.
        averagingThreshold
            A Float specifying the nodal averaging threshold percentage. 0 ≤ **averagingThreshold**
            ≤ 100. The default value is 75.0.
        computeOrder
            A SymbolicConstant specifying the order or the computations to be performed on the
            interested field output variable. Possible values are EXTRAPOLATE_AVERAGE_COMPUTE,
            EXTRAPOLATE_COMPUTE_AVERAGE, EXTRAPOLATE_COMPUTE, EXTRAPOLATE_COMPUTE_DISCONTINUITIES,
            and RAW_DATA. The default value is EXTRAPOLATE_COMPUTE_AVERAGE.
        numericForm
            A SymbolicConstant specifying the numeric form in which to display results that
            contain complex numbers. Possible values are COMPLEX_MAGNITUDE, COMPLEX_PHASE, REAL,
            IMAGINARY, and COMPLEX_MAG_AT_ANGLE. The default value is REAL.
        complexAngle
            A Float specifying the angle (in degrees) at which to display results that contain
            complex numbers when **numericForm = COMPLEX_MAG_AT_ANGLE = COMPLEX_MAG_AT_ANGLE**. The
            default value is 0.0.
        sectionPoint
            A Dictionary with String keys and String values. Each key specifies a region in the
            model; the corresponding value specifies a section point within that region. For
            example:
            
            .. code-block:: python
            
                sectionPoint = {
                    'shell < MAT > < 7 section points >': 'SPOS, (fraction = 1.0)', 
                    'shell < MAT > < 5 section points >': 'SPOS, (fraction = 1.0)', 
                }
            
        refinementType
            A SymbolicConstant specifying the type of the FieldOutput object. Possible values for
            the SymbolicConstant are NO_REFINEMENT, INVARIANT and COMPONENT. Default argument is
            NO_REFINEMENT. **refinementType** is mandetory if **variableLabel** has an INVARIANT or a
            COMPONENT.
        refinementLabel
            A String specifying the Label of FieldOutput object. This is required only if the
            **refinementType** is INVARIANT or COMPONENT.
        displayOutputPosition
            A SymbolicConstant specifying the position from which to obtain the data. Possible
            values are NODAL, INTEGRATION_POINT, ELEMENT_FACE, ELEMENT_NODAL, ELEMENT_CENTROID,
            WHOLE_ELEMENT, WHOLE_REGION, WHOLE_PART_INSTANCE, WHOLE_MODEL, and GENERAL_PARTICLE.

        Returns
        -------
        OdbMeshRegionData
            An :py:class:`~abaqus.Field.OdbMeshRegionData.OdbMeshRegionData` object.

        Raises
        ------
        TextException
        """
        self.odbMeshRegionData = OdbMeshRegionData(
            odbFileName,
            variableLabel,
            stepIndex,
            frameIndex,
            outputPosition,
            dataType,
            storageType,
            quantityToPlot,
            averageElementOutput,
            useRegionBoundaries,
            regionBoundaries,
            includeFeatureBoundaries,
            featureAngle,
            averageOnlyDisplayed,
            averagingThreshold,
            computeOrder,
            numericForm,
            complexAngle,
            sectionPoint,
            refinementType,
            refinementLabel,
            displayOutputPosition,
        )
        return self.odbMeshRegionData



from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class ProbeReport:
    """The ProbeReport object is used to store settings associated with tabular reports of
    probe data. The ProbeReport object has no constructor. Abaqus creates the
    **defaultProbeReport** and the **probeReport** members when you import the Visualization
    module. When probing is initiated for the first time, the values in the **probeReport**
    member are initialized using the values from the **defaultProbeReport** member.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import visualization
            session.defaultProbeReport
            session.probeReport
    """

    @abaqus_method_doc
    def setValues(
        self,
        options: str = None,
        numColumns: int = 80,
        numDigits: int = 6,
        numFormat: SymbolicConstant = ENGINEERING,
        pageWidth: SymbolicConstant = NO_LIMIT,
        printTotal: Boolean = OFF,
        printMinMax: Boolean = OFF,
    ):
        """This method modifies the ProbeReport object.

        Parameters
        ----------
        options
            None or a ProbeReport object specifying values to be copied. If other arguments are also
            supplied to setValues, they will override the values in **options**. The default value is
            None.
        numColumns
            An Int specifying the number of columns in the report file. This argument is valid only
            when **pageWidth** = SPECIFY. The default value is 80.
        numDigits
            An Int specifying the number of significant digits to be written for decimal values. The
            default value is 6.
        numFormat
            A SymbolicConstant specifying the number format to be used when formatting decimal
            values. Possible values are AUTOMATIC, ENGINEERING, and SCIENTIFIC. The default value is
            ENGINEERING.
        pageWidth
            A SymbolicConstant specifying the page width format. Possible values are NO_LIMIT and
            SPECIFY. The default value is NO_LIMIT.
        printTotal
            A Boolean specifying whether to print the total value of either the field output result
            (when **probeObject** = ”ODB”) or the **x**- and **y**-coordinates (when **probeObject** = XYPlot).
            The default value is OFF.
        printMinMax
            A Boolean specifying whether to print the minimum and maximum values of either the field
            output result (when **probeObject** = ”ODB”) or the **x**- and **y**-coordinates (when
            **probeObject** = XYPlot). The default value is OFF.
        """
        ...



from .._decorators import abaqus_class_doc


@abaqus_class_doc
class ContactControl:
    """The ContactControl object is the abstract base type for other ContactControl objects.
    The ContactControl object has no explicit constructor, members, or methods.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].contactControls[name]
    """

    ...



from .Metal.Annealing.AnnealTemperature import AnnealTemperature
from .Metal.Cyclic.CycledPlastic import CycledPlastic
from .Metal.Cyclic.CyclicHardening import CyclicHardening
from .Metal.ORNL.Ornl import Ornl
from .Metal.RateDependent.RateDependent import RateDependent
from .Potential import Potential
from .TensileFailure import TensileFailure
from ...UtilityAndView.abaqusConstants import *
from ..._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class Plastic:
    r"""The Plastic object specifies a metal plasticity model.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].Plastic
            import odbMaterial
            session.odbs[name].materials[name].Plastic

        The table data for this object are:

        - If **hardening** = ISOTROPIC, or if **hardening** = COMBINED and **dataType** = HALF_CYCLE, the table data specify the following:
        
            - Yield stress.
            - Plastic strain.
            - Equivalent plastic strain rate, :math:`\dot{\bar{\varepsilon}} p l`.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **hardening** = COMBINED and **dataType** = STABILIZED, the table data specify the following:
        
            - Yield stress.
            - Plastic strain.
            - Strain range, if the data depend on strain range.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **hardening** = COMBINED and **dataType** = PARAMETERS, the table data specify the following:
        
            - Yield stress at zero Plastic strain.
            - The first kinematic hardening parameter, :math:`C_{1}`.
            - The first kinematic hardening parameter, :math:`\gamma_{1}`.
            - If applicable, the second kinematic hardening parameter, :math:`C_{2}`.
            - If applicable, the second kinematic hardening parameter, :math:`\gamma_{2}`.
            - Etc.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **hardening** = KINEMATIC, the table data specify the following:
        
            - Yield stress.
            - Plastic strain.
            - Temperature, if the data depend on temperature.
        - If **hardening** = JOHNSON_COOK, the table data specify the following:
        
            - :math:`A`.
            - :math:`B`.
            - :math:`\mathrm{n}`.
            - :math:`\mathrm{m}`.
            - Melting temperature.
            - Transition temperature.
        - If **hardening** = USER, the table data specify the following:
        
            - Hardening properties.

        The corresponding analysis keywords are:

        - PLASTIC
    """

    #: A :py:class:`~abaqus.Material.Plastic.Metal.RateDependent.RateDependent.RateDependent` object.
    rateDependent: RateDependent = RateDependent(((),))

    #: A :py:class:`~abaqus.Material.Plastic.Potential.Potential` object.
    potential: Potential = Potential(((),))

    #: A :py:class:`~abaqus.Material.Plastic.Metal.Cyclic.CyclicHardening.CyclicHardening` object.
    cyclicHardening: CyclicHardening = CyclicHardening(((),))

    #: An :py:class:`~abaqus.Material.Plastic.Metal.ORNL.Ornl.Ornl` object.
    ornl: Ornl = Ornl()

    #: A :py:class:`~abaqus.Material.Plastic.Metal.Cyclic.CycledPlastic.CycledPlastic` object.
    cycledPlastic: CycledPlastic = CycledPlastic(((),))

    #: An :py:class:`~abaqus.Material.Plastic.Metal.Annealing.AnnealTemperature.AnnealTemperature` object.
    annealTemperature: AnnealTemperature = AnnealTemperature(((),))

    #: A :py:class:`~abaqus.Material.Plastic.TensileFailure.TensileFailure` object.
    tensileFailure: TensileFailure = TensileFailure()

    @abaqus_method_doc
    def __init__(
        self,
        table: tuple,
        hardening: SymbolicConstant = ISOTROPIC,
        rate: Boolean = OFF,
        dataType: SymbolicConstant = HALF_CYCLE,
        strainRangeDependency: Boolean = OFF,
        numBackstresses: int = 1,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
    ):
        """This method creates a Plastic object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].Plastic
                session.odbs[name].materials[name].Plastic

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.
        hardening
            A SymbolicConstant specifying the type of hardening. Possible values are ISOTROPIC,
            KINEMATIC, COMBINED, JOHNSON_COOK, and USER. The default value is ISOTROPIC.
        rate
            A Boolean specifying whether the data depend on rate. The default value is OFF.
        dataType
            A SymbolicConstant specifying the type of combined hardening. This argument is only
            valid if **hardening** = COMBINED. Possible values are HALF_CYCLE, PARAMETERS, and
            STABILIZED. The default value is HALF_CYCLE.
        strainRangeDependency
            A Boolean specifying whether the data depend on strain range. This argument is only
            valid if **hardening** = COMBINED and **dataType** = STABILIZED. The default value is OFF.
        numBackstresses
            An Int specifying the number of backstresses. This argument is only valid if
            **hardening** = COMBINED. The default value is 1.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.

        Returns
        -------
        Plastic
            A :py:class:`~abaqus.Material.Plastic.Plastic.Plastic` object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the Plastic object.

        Raises
        ------
        RangeError
        """
        ...



from .Constraint import Constraint
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class MultipointConstraint(Constraint):
    """The MultipointConstraint object defines a constraint between a group of
    MultipointConstraint nodes located on a region and a reference point.
    The MultipointConstraint object is derived from the ConstrainedSketchConstraint object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].constraints[name]

        The corresponding analysis keywords are:

        - MPC
    """

    #: A Boolean specifying whether the constraint is suppressed or not. The default value is
    #: OFF.
    suppressed: Boolean = OFF

    #: A String specifying the constraint repository key.
    name: str

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the surface on which the MultipointConstraint nodes are
    #: located.
    surface: Region

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the constraint control point.
    controlPoint: Region

    #: A SymbolicConstant specifying the MPC type of the constraint. Possible values are
    #: BEAM_MPC, ELBOW_MPC, PIN_MPC, LINK_MPC, TIE_MPC, and USER_MPC.
    mpcType: SymbolicConstant

    #: None or a DatumCsys object specifying the initial orientation of the local coordinate
    #: system for the MultipointConstraint's degrees of freedom. If **localCsys** = None, the
    #: MultipointConstraint is defined in the global coordinate system. The default value is
    #: None.
    csys: str = None

    #: An Int specifying to differentiate between different constraint types in a user-defined
    #: MultipointConstraint. The default value is 0.The **userType** argument applies only when
    #: **mpcType** = USER_MPC.
    userType: int = 0

    #: A SymbolicConstant specifying the mode of the constraint when it is user-defined.
    #: Possible values are DOF_MODE_MPC and NODE_MODE_MPC. The default value is
    #: DOF_MODE_MPC.The **userMode** argument applies only when **mpcType** = USER_MPC.
    userMode: SymbolicConstant = DOF_MODE_MPC

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        surface: Region,
        controlPoint: Region,
        mpcType: SymbolicConstant,
        csys: str = None,
        userType: int = 0,
        userMode: SymbolicConstant = DOF_MODE_MPC,
    ):
        """This method creates a MultipointConstraint object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].MultipointConstraint

        Parameters
        ----------
        name
            A String specifying the constraint repository key.
        surface
            A :py:class:`~abaqus.Region.Region.Region` object specifying the surface on which the MultipointConstraint nodes are
            located.
        controlPoint
            A :py:class:`~abaqus.Region.Region.Region` object specifying the constraint control point.
        mpcType
            A SymbolicConstant specifying the MPC type of the constraint. Possible values are
            BEAM_MPC, ELBOW_MPC, PIN_MPC, LINK_MPC, TIE_MPC, and USER_MPC.
        csys
            None or a DatumCsys object specifying the initial orientation of the local coordinate
            system for the MultipointConstraint's degrees of freedom. If **localCsys** = None, the
            MultipointConstraint is defined in the global coordinate system. The default value is
            None.
        userType
            An Int specifying to differentiate between different constraint types in a user-defined
            MultipointConstraint. The default value is 0.The **userType** argument applies only when
            **mpcType** = USER_MPC.
        userMode
            A SymbolicConstant specifying the mode of the constraint when it is user-defined.
            Possible values are DOF_MODE_MPC and NODE_MODE_MPC. The default value is
            DOF_MODE_MPC.The **userMode** argument applies only when **mpcType** = USER_MPC.

        Returns
        -------
        MultipointConstraint
            A :py:class:`~abaqus.Constraint.MultipointConstraint.MultipointConstraint` object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(
        self,
        csys: str = None,
        userType: int = 0,
        userMode: SymbolicConstant = DOF_MODE_MPC,
    ):
        """This method modifies the MultipointConstraint object.

        Parameters
        ----------
        csys
            None or a DatumCsys object specifying the initial orientation of the local coordinate
            system for the MultipointConstraint's degrees of freedom. If **localCsys** = None, the
            MultipointConstraint is defined in the global coordinate system. The default value is
            None.
        userType
            An Int specifying to differentiate between different constraint types in a user-defined
            MultipointConstraint. The default value is 0.The **userType** argument applies only when
            **mpcType** = USER_MPC.
        userMode
            A SymbolicConstant specifying the mode of the constraint when it is user-defined.
            Possible values are DOF_MODE_MPC and NODE_MODE_MPC. The default value is
            DOF_MODE_MPC.The **userMode** argument applies only when **mpcType** = USER_MPC.
        """
        ...



from .BoundaryConditionState import BoundaryConditionState
from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc


@abaqus_class_doc
class ElectricPotentialBCState(BoundaryConditionState):
    """The ElectricPotentialBCState object stores the propagating data for a electrical
    potential boundary condition in a step. One instance of this object is created
    internally by the ElectricPotentialBC object for each step. The instance is also deleted
    internally by the ElectricPotentialBC object.
    The ElectricPotentialBCState object has no constructor or methods.
    The ElectricPotentialBCState object is derived from the BoundaryConditionState object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
            mdb.models[name].steps[name].boundaryConditionStates[name]

        The corresponding analysis keywords are:

        - BOUNDARY
    """

    #: A Float specifying the electrical potential magnitude.
    magnitude: float = None

    #: A SymbolicConstant specifying the propagation state of the electrical potential
    #: magnitude. Possible values are UNSET, SET, UNCHANGED, FREED, and MODIFIED.
    magnitudeState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the amplitude reference. Possible
    #: values are UNSET, SET, UNCHANGED, FREED, and MODIFIED.
    amplitudeState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the BoundaryConditionState object. Possible values are:
    #: 
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - PROPAGATED_FROM_BASE_STATE
    #: - MODIFIED_FROM_BASE_STATE
    #: - DEACTIVATED_FROM_BASE_STATE
    #: - BUILT_INTO_MODES
    status: SymbolicConstant = None

    #: A String specifying the name of the amplitude reference. The String is empty if the
    #: boundary condition has no amplitude reference.
    amplitude: str = ""



import typing

from .StructuralDampingByFrequencyComponent import StructuralDampingByFrequencyComponent

StructuralDampingByFrequencyComponentArray = typing.List[StructuralDampingByFrequencyComponent]



import os
import sys
from abaqus.Odb.OdbCommands import *
from abaqus.UtilityAndView.BackwardCompatibility import BackwardCompatibility
from abaqus.Odb.OdbSequenceAnalyticSurfaceSegment import OdbSequenceAnalyticSurfaceSegment

def openOdb(name: str, *args, **kwargs) -> Odb:
    abaqus = 'abaqus'
    if 'ABAQUS_BAT_PATH' in os.environ.keys():
        abaqus = os.environ['ABAQUS_BAT_PATH']

    filePath = os.path.abspath(sys.argv[0])

    try:  # If it is a jupyter notebook
        import ipynbname

        filePath = ipynbname.path()
        os.system(f"jupyter nbconvert --to python {filePath}")
        filePath = filePath.replace(".ipynb", ".py")
    except:
        pass
    os.system(f'{abaqus} python {filePath}')
    sys.exit()
    return Odb(name)

def AnalyticSurfaceProfile() -> OdbSequenceAnalyticSurfaceSegment:
    """This method creates a OdbSequenceAnalyticSurfaceSegment object.
    
    Returns
    -------
    OdbSequenceAnalyticSurfaceSegment
        An :py:class:`~abaqus.Odb.OdbSequenceAnalyticSurfaceSegment.OdbSequenceAnalyticSurfaceSegment` object.
    """
    return OdbSequenceAnalyticSurfaceSegment()

backwardCompatibility = BackwardCompatibility()



from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc


@abaqus_class_doc
class StepOption:
    """A StepOption is an object used to define step options in a design response.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import optimization
            mdb.models[name].optimizationTasks[name].designResponses[name].stepOptions[i]
    """

    #: The SymbolicConstant ALL or an Int specifying the lower mode in the range of modes to
    #: consider in the step. **lowerMode** is ignored for steps without modes. The default value
    #: is ALL.
    lowerMode: SymbolicConstant = ALL

    #: The SymbolicConstant ALL or an Int specifying the upper mode in the range of modes to
    #: consider in the step. **upperMode** is ignored for steps without modes. The default value
    #: is ALL.
    upperMode: SymbolicConstant = ALL

    #: The SymbolicConstant ALL or a String specifying the name of the load case. **loadCase** is
    #: ignored when the specified **step** does not contain a load case. The default value is
    #: ALL.
    loadCase: SymbolicConstant = ALL

    #: The SymbolicConstant ALL or a String specifying the name of the step. The default value
    #: is ALL.
    step: SymbolicConstant = ALL

    #: A string specifying the name of the model from which the steps are supposed to be used
    #: in the design response. Specify only if the steps are not from the current model.
    model: str = ""
